@@ -1,12 +1,10 @@
 from Products.PythonScripts.standard import url_quote
 from Products.CMFCore.utils import getToolByName
 from zope.interface import implements
-from zope.component import getUtility
 from Products.Five.browser import BrowserView
 from Acquisition import aq_inner
-
 from Products.TinyMCE.browser.interfaces.style import ITinyMCEStyle
-from Products.TinyMCE.interfaces.utility import ITinyMCE
+
 
 class TinyMCEStyle(BrowserView):
     """TinyMCE Style"""
@@ -14,7 +12,7 @@ class TinyMCEStyle(BrowserView):
 
     def getStyle(self):
         """Returns a stylesheet with all content styles"""
-        
+
         registry = getToolByName(aq_inner(self.context), 'portal_css')
         registry_url = registry.absolute_url()
         context = aq_inner(self.context)
@@ -24,18 +22,16 @@ class TinyMCEStyle(BrowserView):
         result = []
 
         for style in styles:
-            if style.getMedia() not in ('print', 'projection') and style.getRel()=='stylesheet' :
+            if style.getMedia() not in ('print', 'projection') and style.getRel() == 'stylesheet':
                 src = "<!-- @import url(%s/%s/%s); -->" % (registry_url, skinname, style.getId())
                 result.append(src)
+
+        # BBB 2010-07-24 Support Plone 3
+        portal_migration = getToolByName(self.context, 'portal_migration')
+        if hasattr(portal_migration, 'getInstanceVersionTuple'):
+            major_version = portal_migration.getInstanceVersionTuple()[0]
+            if major_version == 3:
+                css = self.context.restrictedTraverse('tiny_mce_plone3.css')(self.context)
+                result.append(css)
+
         return "\n".join(result)
-
-
-class Plone3TinyStyle(TinyMCEStyle):
-    """Use this view as content_css to support plone3 with tiny > 1.1rc8"""
-
-    def __call__(self):
-        portal_tinymce = getToolByName(self.context, 'portal_tinymce')
-        css = portal_tinymce.restrictedTraverse('@@tinymce-getstyle')()
-        extended_css = portal_tinymce.restrictedTraverse('tiny_mce_plone3.css')(self.context)
-        css += extended_css
-        return css
