@@ -1,22 +1,19 @@
-try:
-    from zope.component.hooks import getSite
-    getSite  #Pyflakes
-except ImportError:
-    from zope.app.component.hooks import getSite
 from zope.interface import implements
 from zope.schema.fieldproperty import FieldProperty
-from zope.component import getUtility
+from zope.component import getUtility, queryUtility
 from zope.interface import classProvides
 from AccessControl import ClassSecurityInfo
 from Acquisition import aq_base
 from Acquisition import aq_inner
 from Acquisition import aq_parent
-from Products.Archetypes.interfaces import IBaseObject
 from Products.Archetypes.interfaces.field import IImageField
 from Products.Archetypes.Field import ImageField
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.interfaces._content import IFolderish
 from plone.app.layout.navigation.root import getNavigationRootObject
+from plone.outputfilters.filters.resolveuid_and_caption import IImageCaptioningEnabler
+from plone.outputfilters.filters.resolveuid_and_caption import IResolveUidsEnabler
+from Products.CMFCore.interfaces import ISiteRoot
 try:
     import json
 except:
@@ -568,14 +565,8 @@ class TinyMCE(SimpleItem):
 
     security.declareProtected('View', 'getContentType')
     def getContentType(self, object=None, fieldname=None):
-        context = aq_base(object)
-        if IBaseObject.providedBy(context):
-            if fieldname is None:
-                field = context.getPrimaryField()
-            else:
-                field = context.getField(fieldname) or getattr(context, fieldname, None)
-            if field and hasattr(aq_base(field), 'getContentType'):
-                return field.getContentType(context)
+        if hasattr(object, 'getContentType'):
+            return object.getContentType(fieldname)
         return 'text/html'
 
     security.declareProtected('View', 'getConfiguration')
@@ -630,9 +621,6 @@ class TinyMCE(SimpleItem):
         if not redefine_parastyles:
             if isinstance(self.tablestyles, StringTypes):
                 for tablestyle in self.tablestyles.split('\n'):
-                    if not tablestyle:
-                        # empty line
-                        continue
                     tablestylefields = tablestyle.split('|')
                     tablestyletitle = tablestylefields[0]
                     tablestyleid = tablestylefields[1]
@@ -647,9 +635,6 @@ class TinyMCE(SimpleItem):
             if isinstance(self.styles, StringTypes):
                 styles = []
                 for style in self.styles.split('\n'):
-                    if not style:
-                        # empty line
-                        continue
                     stylefields = style.split('|')
                     styletitle = stylefields[0]
                     if request is not None:
@@ -721,18 +706,10 @@ class TinyMCE(SimpleItem):
         else:
             results['contextmenu'] = False
 
-        portal = getSite()
-        results['portal_url'] = aq_inner(portal).absolute_url()
-        nav_root = getNavigationRootObject(context, portal)
-        results['navigation_root_url'] = nav_root.absolute_url()
-
         if self.content_css and self.content_css.strip() != "":
             results['content_css'] = self.content_css
         else:
-            results['content_css'] = '/'.join([
-                results['portal_url'],
-                self.getId(),
-                "@@tinymce-getstyle"])
+            results['content_css'] = self.absolute_url() + """/@@tinymce-getstyle"""
 
         if self.link_using_uids:
             results['link_using_uids'] = True
@@ -755,6 +732,11 @@ class TinyMCE(SimpleItem):
 
         results['entity_encoding'] = self.entity_encoding
 
+        portal = getUtility(ISiteRoot)
+        results['portal_url'] =  aq_inner(portal).absolute_url()
+        nav_root = getNavigationRootObject(context, portal)
+        results['navigation_root_url'] = nav_root.absolute_url()
+
         props = getToolByName(self, 'portal_properties')
         livesearch = props.site_properties.getProperty('enable_livesearch', False)
         if livesearch:
@@ -791,3 +773,25 @@ class TinyMCE(SimpleItem):
             results['document_url'] = results['portal_url']
 
         return json.dumps(results)
+
+
+class ImageCaptioningEnabler(object):
+    implements(IImageCaptioningEnabler)
+    
+    @property
+    def available(self):
+        tinymce = queryUtility(ITinyMCE)
+        if tinymce is not None:
+            return tinymce.allow_captioned_images
+        return False
+
+
+class ResolveUidsEnabler(object):
+    implements(IResolveUidsEnabler)
+
+    @property
+    def available(self):
+        tinymce = queryUtility(ITinyMCE)
+        if tinymce is not None:
+            return tinymce.link_using_uids
+        return False
